summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNorbert Preining <preining@logic.at>2007-06-22 07:50:20 +0000
committerNorbert Preining <preining@logic.at>2007-06-22 07:50:20 +0000
commit020818c8528be67cdbf2179b8a63590daf2fa1a2 (patch)
treeb217936f2975390ef70f35d6d004d048249c9a7b
parentd6d4a615499ffae77ecbcb40d537ad581e229c7e (diff)
Add documentation of zip file inclusion of tlpobj file
fix some tlpsrc2tlpobj stuff git-svn-id: svn://tug.org/texlive/trunk@4489 c570f23f-e606-0410-a88d-b1316a301751
-rwxr-xr-xMaster/tlpkg/bin/tlpsrc2tlpobj.pl8
-rw-r--r--Master/tlpkg/doc/Perl-API.txt6
2 files changed, 10 insertions, 4 deletions
diff --git a/Master/tlpkg/doc/Perl-API.txt b/Master/tlpkg/doc/Perl-API.txt
index 2f92a6000a9..9d675d33dcb 100644
--- a/Master/tlpkg/doc/Perl-API.txt
+++ b/Master/tlpkg/doc/Perl-API.txt
@@ -72,6 +72,12 @@ Input/Output
the zipfile name is
$zipname.$arch.zip
+ All the arch independent zip files ALSO contain the
+ respective TLPOBJ file in
+ .tlpobj/$name.tlpobj
+ SO $zipname.zip does contain this tlpobj file, while
+ $zipname.$arch.zip does NOT.
+
(Compatibility with the scheme used before)
diff --git a/Master/tlpkg/bin/tlpsrc2tlpobj.pl b/Master/tlpkg/bin/tlpsrc2tlpobj.pl
index 6b3a57282cb..6e4435d1c9d 100755
--- a/Master/tlpkg/bin/tlpsrc2tlpobj.pl
+++ b/Master/tlpkg/bin/tlpsrc2tlpobj.pl
@@ -1,7 +1,7 @@
#!/usr/bin/env perl
#
# tlpsrc2tlpobj.pl
# convert a set of tlsrc files (given as arguments) into tlp
# Copyright 2007 Norbert Preining
#
# This file is licensed under the GNU General Public Licence version 2
@@ -25,7 +25,7 @@ use File::Path;
my $opt_master = "/src/TeX/texlive-svn/Master";
-my $opt_outputdir = "./tlp";
+my $opt_outputdir = "./tlpobj";
our $opt_debug = 0;
my $man = 0;
my $help = 0;
@@ -53,9 +53,9 @@ $tltree->init_from_svn;
foreach my $f (@ARGV) {
my $tlsrc = new TeXLive::TLPSRC;
$tlsrc->from_file($f);
- my $tlp = $tlsrc->make_tlp($tltree);
+ my $tlp = $tlsrc->make_tlpobj($tltree);
my $name = $tlp->name;
- open(FOO,">$opt_outputdir/$name.tlp") or die "Cannot create $opt_outputdir/$name.tlp!";
+ open(FOO,">$opt_outputdir/$name.tlpobj") or die "Cannot create $opt_outputdir/$name.tlpobj!";
$tlp->writeout(\*FOO);
close(FOO);
}
@@ -1,7 +1,7 @@
#
# tlpsrc2tlpobj.pl
-# convert a set of tlsrc files (given as arguments) into tlp
+# convert a set of tlpsrc files (given as arguments) into tlpobj
# Copyright 2007 Norbert Preining
#